@@ -381,7 +381,10 @@
 
                 case 'wakeserver':
                     var mac = request.url.split('=')[1].split('&')[0];
-                    var options = { port: request.url.split('=')[2] };
+                    var options = {
+                        address: request.url.split('=')[2].split('&')[0],
+                        port: request.url.split('=')[3].split('&')[0]
+                    };
                     wakeonlan.wake(mac, options, callback);
                     break;
                 default:
@@ -533,7 +536,6 @@
                         version: app.getVersion(),
                         deviceName: os.hostname(),
                         deviceId: os.hostname(),
-                        supportsTransparentWindow: supportsTransparentWindow(),
                         plugins: pluginFiles.filter(function (f) {
 
                             return f.indexOf('.js') != -1;
@@ -780,11 +782,6 @@
         return false;
     }
 
-    function supportsTransparentWindow() {
-
-        return true;
-    }
-
     function getWindowStateDataPath() {
 
         var path = require("path");
@@ -983,6 +980,11 @@
 
             getWebContents().on('dom-ready', setStartInfo);
 
+            getWebContents().on('new-window', (event, url, frameName, disposition, options, additionalFeatures, referrer, postBody) => {
+                event.preventDefault()
+                electron.shell.openExternal(url);
+            })
+
             var url = getAppUrl();
 
             addPathIntercepts();
