@@ -1,4 +1,4 @@
-define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'embyRouter', 'appSettings', 'userSettings', 'loading', 'dom', 'require', 'connectionManager'], function (globalize, appHost, playbackManager, pluginManager, events, embyRouter, appSettings, userSettings, loading, dom, require, connectionManager) {
+define(['globalize', 'playbackManager', 'pluginManager', 'events', 'embyRouter', 'appSettings', 'userSettings', 'require', 'connectionManager'], function (globalize, playbackManager, pluginManager, events, embyRouter, appSettings, userSettings, require, connectionManager) {
     'use strict';
 
     function getTextTrackUrl(subtitleStream, serverId) {
@@ -73,20 +73,18 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                 adjustHeaderForEmbeddedScroll: true
             });
 
-            if (appHost.supports('windowtransparency')) {
-                routes.push({
-                    path: 'mpvplayer/video.html',
-                    transition: 'slide',
-                    controller: pluginManager.mapPath(self, 'mpvplayer/video.js'),
-                    type: 'settings',
-                    title: 'Video',
-                    category: 'Playback',
-                    thumbImage: '',
-                    icon: 'tv',
-                    settingsTheme: true,
-                    adjustHeaderForEmbeddedScroll: true
-                });
-            }
+            routes.push({
+                path: 'mpvplayer/video.html',
+                transition: 'slide',
+                controller: pluginManager.mapPath(self, 'mpvplayer/video.js'),
+                type: 'settings',
+                title: 'Video',
+                category: 'Playback',
+                thumbImage: '',
+                icon: 'tv',
+                settingsTheme: true,
+                adjustHeaderForEmbeddedScroll: true
+            });
 
             return routes;
         };
@@ -207,7 +205,7 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
 
             if ((mediaType || '').toLowerCase() == 'video') {
 
-                return appHost.supports('windowtransparency');
+                return true;
             }
             return (mediaType || '').toLowerCase() == 'audio';
         };
@@ -244,6 +242,7 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                 MaxAudioChannels: '6',
                 MinSegments: '1',
                 BreakOnNonKeyFrames: true,
+                ManifestSubtitles: 'vtt',
                 SegmentLength: '3'
             });
 
@@ -357,6 +356,11 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                 Method: 'VideoSideData'
             });
 
+            profile.SubtitleProfiles.push({
+                Format: 'vtt',
+                Method: 'Hls'
+            });
+
             profile.ResponseProfiles = [];
 
             return Promise.resolve(profile);
@@ -370,14 +374,6 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
             return currentSrc;
         };
 
-        function onNavigatedToOsd() {
-
-            if (videoDialog) {
-                videoDialog.classList.remove('mpv-videoPlayerContainer-withBackdrop');
-                videoDialog.classList.remove('mpv-videoPlayerContainer-onTop');
-            }
-        }
-
         function createMediaElement(options) {
 
             return new Promise(function (resolve, reject) {
@@ -388,57 +384,29 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
 
                     require(['css!./libmpv'], function () {
 
-                        loading.show();
-
                         var dlg = document.createElement('div');
 
                         dlg.classList.add('mpv-videoPlayerContainer');
 
-                        if (options.backdropUrl && options.mediaType === 'Video') {
-
-                            dlg.classList.add('mpv-videoPlayerContainer-withBackdrop');
-                            dlg.style.backgroundImage = "url('" + options.backdropUrl + "')";
-                        }
-
-                        if (options.fullscreen && options.mediaType === 'Video') {
-                            dlg.classList.add('mpv-videoPlayerContainer-onTop');
-                        }
-
                         document.body.insertBefore(dlg, document.body.firstChild);
                         videoDialog = dlg;
 
                         var embed = document.createElement('embed');
                         embed.type = 'application/x-mpvjs';
-                        embed.classList.add('mpv-videoPlayer')
-                        embed.addEventListener('message', message)
-                        embed.style.opacity = 0
-
+                        embed.classList.add('mpv-videoPlayer');
+                        embed.addEventListener('message', message);
                         dlg.insertBefore(embed, dlg.firstChild);
-                        libmpv = embed
+                        libmpv = embed;
 
                         addEventListener('ready', async () => {
                             await observeProperty(['pause', 'time-pos', 'duration', 'volume', 'mute', 'eof-reached', 'demuxer-cache-state', 'demuxer-cache-time', 'estimated-vf-fps', 'sub-delay', 'speed', 'core-idle'])
-                            if (options.fullscreen && options.mediaType === 'Video') {
-                                zoomIn(dlg).then(resolve);
-                            } else {
-                                resolve();
-                            }
+                            resolve();
                         }, { once: true })
 
                     });
 
                 } else {
 
-                    if (libmpv) {
-                        libmpv.style.opacity = 0
-                    }
-                    dlg.style.opacity = 1
-                    if (options.backdropUrl && options.mediaType === 'Video') {
-
-                        dlg.classList.add('mpv-videoPlayerContainer-withBackdrop');
-                        dlg.style.backgroundImage = "url('" + options.backdropUrl + "')";
-                    }
-
                     resolve();
                 }
             });
@@ -501,19 +469,24 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
 
 
         self.play = async function (options) {
+            if (options.fullscreen && options.item.MediaType == 'Video') {
+                await embyRouter.showVideoOsd()
+            }
             await displaySync();
             await createMediaElement(options);
             await new Promise((resolve, reject) => {
                 addEventListener('core-playing', resolve, { once: true })
+
                 playInternal(options);
+
+                if (videoDialog) {
+                    if (appSettings.get('mpv-vo') && appSettings.get('mpv-vo') !== 'libmpv' && window.platform === 'win32') {
+                        videoDialog.style.opacity = 0;
+                    } else {
+                        videoDialog.style.opacity = 1;
+                    }
+                }
             })
-            if (libmpv && options.mediaType === 'Video') {
-                libmpv.style.opacity = 1;
-            }
-            if (videoDialog && appSettings.get('mpv-vo') && appSettings.get('mpv-vo') !== 'libmpv' && window.platform === 'win32') {
-                videoDialog.style.opacity = 0;
-            }
-            await showOsd(options);
         };
 
         async function playInternal(options) {
@@ -541,7 +514,6 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                 }
             }
 
-            var fullscreen = options.fullscreen || false;
             var mediaType = options.item.MediaType;
             var playMethod = options.playMethod;
             var startPositionTicks = options.playerStartPositionTicks || 0
@@ -601,8 +573,8 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                 playerOptions["interpolation"] = true
             }
 
-            if (fullscreen) {
-                playerOptions["fullscreen"] = fullscreen
+            if (options.fullscreen && options.item.MediaType == 'Video') {
+                playerOptions["fullscreen"] = true;
             }
 
             if (mediaSource.RunTimeTicks == null || options.item.Type === 'Recording') {
@@ -637,23 +609,6 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
             })
         }
 
-        async function showOsd(options) {
-            if (options.item.MediaType == 'Video') {
-                if (options.fullscreen) {
-                    await embyRouter.showVideoOsd()
-                    onNavigatedToOsd();
-
-                } else {
-                    embyRouter.setTransparency('backdrop');
-
-                    if (videoDialog) {
-                        videoDialog.classList.remove('mpv-videoPlayerContainer-withBackdrop');
-                        videoDialog.classList.remove('mpv-videoPlayerContainer-onTop');
-                    }
-                }
-            }
-        }
-
         // Save this for when playback stops, because querying the time at that point might return 0
         self.currentTime = function (val) {
 
@@ -990,22 +945,8 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
             return playerState.playbackRate;
         };
 
-        function zoomIn(elem) {
-
-            return new Promise(function (resolve, reject) {
-
-                var duration = 240;
-                elem.style.animation = 'mpvvideoplayer-zoomin ' + duration + 'ms ease-in normal';
-                dom.addEventListener(elem, dom.whichAnimationEvent(), resolve, {
-                    once: true
-                });
-            });
-        }
-
         function destroyInternal() {
 
-            embyRouter.setTransparency('none');
-
             appSettings.set('mpv-volume', playerState.volume);
 
             if (orgRefreshRate != curRefreshRate) {
@@ -1073,7 +1014,7 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                 audioChannels = '5.1,stereo';
             }
             else if (audioChannels === '7.1') {
-                audioChannels = '7.1,stereo';
+                audioChannels = '7.1,5.1,stereo';
             }
 
             var audioChannelsFilter = getAudioChannelsFilter(mediaType);
